| Title: | Visualise OMOP Results using 'shiny' Applications |
|---|---|
| Description: | Visualise results obtained from analysing data mapped to the Observational Medical Outcomes Partnership (OMOP) common data model using 'shiny' applications. |
| Authors: | Martí Català [aut, cre] (ORCID: <https://orcid.org/0000-0003-3308-9905>), Yuchen Guo [aut] (ORCID: <https://orcid.org/0000-0002-0847-4855>), Edward Burn [ctb] (ORCID: <https://orcid.org/0000-0002-9286-1128>), Nuria Mercade-Besora [ctb] (ORCID: <https://orcid.org/0009-0006-7948-3747>), Elin Rowlands [ctb] (ORCID: <https://orcid.org/0009-0005-5166-0417>), Cecilia Campanile [ctb] (ORCID: <https://orcid.org/0009-0007-6629-4661>) |
| Maintainer: | Martí Català <[email protected]> |
| License: | Apache License (>= 2) |
| Version: | 0.7.0 |
| Built: | 2026-05-27 11:02:40 UTC |
| Source: | https://github.com/ohdsi/omopviewer |
Default panels defined in the package.
defaultPanels()defaultPanels()
Names of the default panels defined in the package.
defaultPanels()defaultPanels()
Export and launch a static shiny specific to the provided results.
exportStaticApp( result, directory, logo = NULL, title = "", background = TRUE, summary = TRUE, report = FALSE, panelDetails = panelDetailsFromResult(result), panelStructure = NULL, theme = NULL, template = NULL, updateButtons = TRUE, includeOneChoiceFilters = TRUE, open = rlang::is_interactive() )exportStaticApp( result, directory, logo = NULL, title = "", background = TRUE, summary = TRUE, report = FALSE, panelDetails = panelDetailsFromResult(result), panelStructure = NULL, theme = NULL, template = NULL, updateButtons = TRUE, includeOneChoiceFilters = TRUE, open = rlang::is_interactive() )
result |
A summarised_result object. |
directory |
Directory to create the shiny. |
logo |
Name of a logo or path to a logo. If NULL no logo is obtained from theme. |
title |
title of the shiny |
background |
Whether to include a background panel. Background panel content will be controlled from the generated background.md file. |
summary |
Whether to include a panel with a summary of content in the
|
report |
Whether to include a quarto report. |
panelDetails |
A named list to provide details for each one of the
panels, such as: result_id, result_type, title, icon, filters and content.
By default it is created using the |
panelStructure |
A named list of panel identifiers to organise them in
drop-down menus. Identifiers names are the ones used in |
theme |
Specify the theme for the Shiny application. You can either
select a predefined theme provided by the package (e.g., |
template |
Path to a template |
updateButtons |
Whether to include update buttons for visualisations. |
includeOneChoiceFilters |
Whether to include filter buttons for filters with just one choice. |
open |
Whether to open the shiny app project. |
The shiny app will be created in directory.
exportStaticApp( result = omopgenerics::emptySummarisedResult(), directory = tempdir() )exportStaticApp( result = omopgenerics::emptySummarisedResult(), directory = tempdir() )
Get one of the default pre-built panels.
getPanel(panelId)getPanel(panelId)
panelId |
Name of the one of the default panels. Use |
A panel definition.
getPanel("incidence")getPanel("incidence")
launchDynamicApp()launchDynamicApp()
Launches the shiny app.
The panels are generated using the following file: https://github.com/OHDSI/OmopViewer/blob/main/data-raw/panels.R.
omopViewerPanelsomopViewerPanels
omopViewerPanelsA list of 26 omopviewer_panel obejcts
GiBleed dataset.The results are generated using the following file: https://github.com/OHDSI/OmopViewer/blob/main/data-raw/results.R.
omopViewerResultsomopViewerResults
omopViewerResultsA summarised_result object with 12,017 rows
OmopViewer themesList the available configured OmopViewer themes
omopViewerThemes()omopViewerThemes()
A character vector with the available OmopViewer themes.
library(OmopViewer) omopViewerThemes()library(OmopViewer) omopViewerThemes()
<summarised_result> object.Obtain default panel details from a <summarised_result> object.
panelDetailsFromResult(result, includeOneChoiceFilters = TRUE)panelDetailsFromResult(result, includeOneChoiceFilters = TRUE)
result |
A |
includeOneChoiceFilters |
Whether to include filters that contain only one choice. |
A list of omop_viewer_panel objects.
panelDetailsFromResult(omopViewerResults)panelDetailsFromResult(omopViewerResults)